//--------------------------------------------------------------------------------------------
/// \file	main.cpp
/// \author	Rob Bateman
/// \brief	Probably the simplest maya exporter code possible. This will work on both linux
/// 		and win32, makes sure that your VisualC++ options has set the correct paths to
/// 		the maya includes and libraries. When compiling on linux, make sure you have
/// 		set the correct paths contained within the makefile that is included.
///
/// 		When compiling under linux, you will need to have gtk2 installed (the file dialog
/// 		code uses it. It would be fairly trivial to strip that out however).
//--------------------------------------------------------------------------------------------

#include <maya/MItDependencyNodes.h>
#include <maya/MFnDependencyNode.h>
#include <maya/MFileIO.h>
#include <maya/MLibrary.h>

#include <fstream>

// generic linux(gtk2) & win32 file dialog code
#include "FileDialog.h"

// link to some fairly funky maya libs. NOTE: The Image library only became part of maya
// from version 4.01 onwards. It is not available in version 4.0
//
#ifdef WIN32
	#pragma comment(lib,"Foundation.lib")
	#pragma comment(lib,"OpenMaya.lib")
	#pragma comment(lib,"OpenMayaFx.lib")
	#pragma comment(lib,"Image.lib")
	#pragma comment(lib,"OpenMayaAnim.lib")
#endif



#ifdef WIN32
int main(int argc,char** argv)
{
#else // hack for linux & gtk

// gtk needs the command line args for initialisation
int   g_argc=0;
char** g_argv=0;

int main(int argc,char** argv)
{
	g_argc=argc;
	g_argv=argv;
#endif
	char InFileName[512]={0};
	char OutFileName[512]={0};

	// both an infile and outfile specified as command line args
	if (argc == 3 )
	{
		strcpy(InFileName,argv[1]);
		strcpy(OutFileName,argv[2]);
	}
	else

	// if only one argument was specified, I'll assume that it is a maya binary
	// or ascii file
	if (argc == 2 )
	{
		// got infile from command line args
		strcpy(InFileName,argv[1]);

		// ask for an outfile
		if(!SaveFileDialog(OutFileName)) {
			return EXIT_FAILURE;
		}
	}
	else

	// no args specified so pop up a couple fo file dialogs
	if (argc == 1 )
	{
		// get in file name
		if(!OpenFileDialog(InFileName)) {
			return EXIT_FAILURE;
		}

		// get out file name
		if(!SaveFileDialog(OutFileName)) {
			return EXIT_FAILURE;
		}
	}
	else {
		std::cerr << "[ERROR] Usage\n\tSimpleExporter [infile.mb|infile.ma] [outfile]\n";
		return EXIT_FAILURE;
	}

	// initialise the maya library - This basically starts up Maya
	MLibrary::initialize(argv[0]);


	// open the file that the user specified
	if( MS::kSuccess == MFileIO::open(InFileName,NULL,true) )
	{
		// open the output file
		std::ofstream ofs(OutFileName);

		// make sure it opened ok
		if(!ofs) {
			std::cerr << "[ERROR] Could not open file for writing " << OutFileName << std::endl;
		}
		else {

			// use an iterator to iterate through all nodes in the scene
			MItDependencyNodes it(MFn::kInvalid);

			// loop through all nodes
			for( ; !it.isDone(); it.next() )
			{
				// attach a function set to this node so we can access some data.
				// the dependency node is just one of many function set types we
				// can use, it forms the base class of all function sets used within the
				// maya API.
				MFnDependencyNode fn(it.item());

				// output a little info about this node
				ofs << "NODE:\t" << fn.name().asChar() << "\tTYPE:\tMFn::" << it.item().apiTypeStr() << std::endl;
			}

			ofs.close();
		}
	}
	else {
		std::cerr << "[ERROR] Could not open file " << InFileName << std::endl;
	}

	// close down maya
	MLibrary::cleanup(0);

	return 0;
}





